@@ -1124,6 +1124,11 @@ static void smtp_connect_inet(SMTP_STATE *state, const char *nexthop,
 		continue;
 		/* XXX Assume there is no code at the end of this loop. */
 	    }
+	    /* Skip MX hosts that lack authorization. */
+	    if (!smtp_tls_authorize_mx_hostname(state->tls, addr->qname)) {
+		continue;
+		/* XXX Assume there is no code at the end of this loop. */
+	    }
 	    /* Disable TLS when retrying after a handshake failure */
 	    if (retry_plain) {
 		state->tls->level = TLS_LEV_NONE;
